@@ -1,4 +1,5 @@
 __all__ = (
+    "AiidaOptimadeException",
     "AiidaEntityNotFound",
     "OptimadeIntegrityError",
     "CausationError",
@@ -6,23 +7,27 @@ __all__ = (
 )
 
 
-class AiidaEntityNotFound(Exception):
+class AiidaOptimadeException(Exception):
+    """Root Exception for aiida-optimade."""
+
+
+class AiidaEntityNotFound(AiidaOptimadeException):
     """Could not find an AiiDA entity in the DB."""
 
 
-class OptimadeIntegrityError(Exception):
-    """A required OPTiMaDe attribute or sub-attribute may be missing.
+class OptimadeIntegrityError(AiidaOptimadeException):
+    """A required OPTIMADE attribute or sub-attribute may be missing.
     Or it may be that the internal data integrity is violated,
     i.e., number of "species_at_sites" does not equal "nsites"
     """
 
 
-class CausationError(Exception):
+class CausationError(AiidaOptimadeException):
     """Cause-and-effect error
 
     Something MUST be done before something else is possible.
     """
 
 
-class AiidaError(Exception):
+class AiidaError(AiidaOptimadeException):
     """Error related to AiiDA data or information."""
